# NKPackage
This is a library for agent-based modeling using _NK-framework_ (Kauffman, 1989). It is designed to ease binary vector manipulations and create performance landscapes.

### Dependencies
- The package is mainly written in `numpy`.
- For faster performance, a _jit_ compiler by `numba` is used
- Other dependencies: `scipy` and `itertools`

### Codebase and contributions
The package is based on the research needs at the [DECIDE lab](https://www.aau.at/digital-age-research-center/decide/) in 2019-2020, and is by no means exhaustive. We will gladly accept pull requests and suggestions to improve the codebase, performance, usability, applicability. Forks are also welcome, but make sure to respect the MIT license.

### Credits
The package is written by Ravshan S.K. Follow me on Twitter [@ravshansk](https://twitter.com/ravshansk).


